@@ -12,6 +12,8 @@ def get_indent(line: str) -> int:
 
 
 def join(lines):
+    if not len(lines):
+        return ""
     indent = get_indent(lines[0])
     return "\n".join(line[indent:] for line in lines).strip()
 
